CsType

Enum CsType 

pub enum CsType {
Show 13 variants Affine, Cartesian, Cylindrical, Ellipsoidal, Linear, Parametric, Polar, Spherical, Vertical, TemporalCount, TemporalMeasure, Ordinal, TemporalDateTime,
}
The type of a coordinate system.

Variants



Affine

An affine coordinate system.



Cartesian

A Cartesian coordinate system with orthogonal straight axes.



Cylindrical

A 3D coordinate system with a polar and a longitudinal axis, plus a straight axis.



Ellipsoidal

A coordinate system on the surface of an ellipsoid using latitude and longitude.



Linear

A 1D coordinate system along a straight line.



Parametric

A coordinate system for parametric values (e.g. pressure levels).



Polar

A 2D coordinate system with a straight radial axis and an angular axis.



Spherical

A 3D coordinate system on a sphere using two angular coordinates plus radius.



Vertical

A 1D coordinate system for height or depth.



TemporalCount

A temporal coordinate system using integer counts of a time unit.



TemporalMeasure

A temporal coordinate system using real-valued measurements of a time unit.



Ordinal

A coordinate system using discrete ordinal values (ranks).



TemporalDateTime

A temporal coordinate system using date-time values.