pub struct DynamicCrs {
pub frame_reference_epoch: f64,
pub deformation_model: Option<DeformationModel>,
}Expand description
Dynamic CRS attributes for a CRS with a time-varying reference frame.
In a dynamic CRS, coordinate values of a point change with time.
WKT2 keyword: DYNAMIC.
Fields
frame_reference_epoch: f64The epoch at which the reference frame is defined (e.g. 2010.0).
deformation_model: Option<DeformationModel>An optional reference to a deformation model or velocity grid.