pub struct Usage {
pub scope: String,
pub area: Option<String>,
pub bbox: Option<BBox>,
pub vertical_extent: Option<VerticalExtent>,
pub temporal_extent: Option<TemporalExtent>,
}Expand description
A scope-extent pairing describing the applicability of a CRS or coordinate operation.
WKT2 keyword: USAGE.
Fields
scope: StringA textual description of the scope (purpose) of the CRS.
area: Option<String>A textual description of the geographic area of applicability.
bbox: Option<BBox>A geographic bounding box describing the area of applicability.
vertical_extent: Option<VerticalExtent>A vertical height range of applicability.
temporal_extent: Option<TemporalExtent>A temporal range of applicability.